{display}
<form action="/admin/mconfig/index/sitemap/manage" method="post" name="module_map" id="module_map">
    <table class="compare-info">
        <thead>
            <tr>
                <td class="compare-product">{label_module}</td>
                <td class="compare-product">{label_changefreq}</td>
                <td class="compare-product">{label_priority}</td>
            </tr>

        </thead>
        <tbody>
            {modules}
            <tr>
                <td class="name">{module_name}</td>
                <td>
                    <select name="changefreq_{module_name}">
                        {changefreq}
                    </select>
                </td>
                <td><input type="text" name="priority_{module_name}" value="{priority}" placeholder="0.5"></td>
            </tr>
            {/modules}
        </tbody>
    </table>
</form>

<div class="form-button-box">
    {button_save}
    {button_generate}
</div>

<style type="text/css">
    .compare-info {
        border-collapse: collapse;
        width: 100%;
        border-top: 1px solid #DDDDDD;
        border-left: 1px solid #DDDDDD;
        margin-bottom: 20px;
    }
    .compare-info thead td, .compare-info thead tr td:first-child {
        color: #000000;
        font-size: 14px;
        font-weight: bold;
        background: #F7F7F7;
        /*text-align: left;*/
    }
    .compare-info tr td:first-child {
        color: #000000;
        font-weight: bold;
        /*text-align: right;*/
    }
    .compare-info td {
        padding: 7px;
        width: 20%;
        color: #4D4D4D;
        text-align: center;
        vertical-align: top;
        border-right: 1px solid #DDDDDD;
        border-bottom: 1px solid #DDDDDD;
    }
    .compare-info .name a {
        font-weight: bold;
    }
    .compare-info .price-old {
        font-weight: bold;
        color: #F00;
        text-decoration: line-through;
    }
    .compare-info .price-new {
        font-weight: bold;
    }
    </style>

    <script type="text/javascript">
        function generate() {
            $.post('/ajax/sitemap/sitemap_admin/action', {'action': '1'}, function(data) {
                var obj = jQuery.parseJSON(data);
                if (obj.status == 'success') {
                    alert('Генерация прошла успешно!');
                }
                if (obj.status == 'error') {
                    alert('Ошибка при генерации!');
                }
            });
        }
    
        $(document).ready(function() {
            $('#form_send').click(function() {
                $('#module_map' ).submit();
                return false;
            });
        });
    
   
    </script>