  CREATE TABLE IF NOT EXISTS `sitemap_config` (
              `module_name` varchar(128) NOT NULL,
              `changefreq` varchar(128) NOT NULL,
              `priority` varchar(128) NOT NULL
                ) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1;